WalletModel class

Constructors

WalletModel({int? organizationID, int? fintechID, String? organizationName, String? mobileNumber, String? name, String? subWallet, double? balance, String? icon, String? cardImage, String? walletTypeID})
WalletModel.fromJson(Map<String, dynamic> json)

Properties

balance double?
getter/setter pair
cardImage String?
getter/setter pair
fintechID int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
icon String?
getter/setter pair
mobileNumber String?
getter/setter pair
name String?
getter/setter pair
organizationID int?
getter/setter pair
organizationName String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subWallet String?
getter/setter pair
walletTypeID String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited