BlockUnblockModel class

Constructors

BlockUnblockModel({required String title, required bool isEnable, required String subTitle})

Properties

hashCode int
The hash code for this object.
no setterinherited
isEnable bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subTitle String
getter/setter pair
title String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited