RupaySecQuestionModel class

Constructors

RupaySecQuestionModel({String? question, bool? isActive})
RupaySecQuestionModel.fromJson(Map<String, dynamic> json)

Properties

hashCode int
The hash code for this object.
no setterinherited
isActive bool?
getter/setter pair
question String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJsonArray(List jsonArray) List<RupaySecQuestionModel>