LimitsMaster class

Constructors

LimitsMaster({required String? mode, required String? limitType, required double? minLimit, required double? maxLimit})
LimitsMaster.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
limitType String?
final
maxLimit double?
final
minLimit double?
final
mode String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited