Table1 class

Constructors

Table1({String? rRN, String? rupayCardRefNo, String? orderID, String? uniqueID, String? mobilenumber, String? poiname, String? entityName, double? amount, String? trxnStatus, String? responseDesc, String? narration, String? insertDatetime, String? category})
Table1.fromJson(Map<String, dynamic> json)

Properties

amount double?
getter/setter pair
category String?
getter/setter pair
entityName String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
insertDatetime String?
getter/setter pair
mobilenumber String?
getter/setter pair
narration String?
getter/setter pair
orderID String?
getter/setter pair
poiname String?
getter/setter pair
responseDesc String?
getter/setter pair
rRN String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
rupayCardRefNo String?
getter/setter pair
trxnStatus String?
getter/setter pair
uniqueID String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited