SendMonyBankController class

Inheritance
  • Object
  • GetLifeCycle
  • DisposableInterface
  • GetxController
  • SendMonyBankController
Implemented types

Constructors

SendMonyBankController()

Properties

auth authrepository
final
bankTransferIfscMmidModel ↔ Rx<BankTransferIfscMmidModel>
getter/setter pair
chargesList List<Charges>
getter/setter pair
fundLimitCheckModel ↔ Rx<FundLimitCheckModel>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
impsChargesModel ↔ Rx<ImpsChargesModel>
getter/setter pair
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
ipAddress String
getter/setter pair
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
listeners int
no setterinherited
onDelete → InternalFinalCallback<void>
Internal callback that starts the cycle of this controller.
finalinherited
onStart → InternalFinalCallback<void>
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclases. This method should be internal and is required to define the lifetime cycle of the subclass.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validatePaymentModel ↔ Rx<ValidatePaymentModel>
getter/setter pair

Methods

$configureLifeCycle() → void
inherited
addListener(GetStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, GetStateUpdate listener) → Disposer
inherited
callIMPSFundingLimitCheck(BuildContext context, String? mobileNumber, String accNo, String bnkName, String ifscCode, String amt, String custMobNo, String beneficiaryName, String type, String mBenfMobNo, String mMMIDCODE, String senderName, String senderMmid, String pan, String accountNo) → dynamic
dispose() → void
inherited
disposeId(Object id) → void
To dispose an id from future updates(), this ids are registered by GetBuilder() or similar, so is a way to unlink the state change with the Widget from the Controller.
inherited
impsCharges(BuildContext context) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens() → void
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
inherited
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
inherited
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
ProccedToImpsCharges(BuildContext context, String mobileNumber, String accNo, String bnkName, String ifscCode, String amt, String custMobNo, String beneficiaryName, String type, String mBenfMobNo, String mMMIDCODE, String senderName, String senderMmid, String pan, String accountNo) Future<void>
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
setBalance(FundLimitCheckModel value) → void
setBankTransValue(BankTransferIfscMmidModel value) → void
setCharges(ImpsChargesModel value) → void
setValidatePayment(ValidatePaymentModel value) → void
showAlertDialog1(BuildContext context, String title, String subTitle) → dynamic
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Rebuilds GetBuilder each time you call update(); Can take a List of ids, that will only update the matching GetBuilder( id: ), ids can be reused among GetBuilders like group tags. The update will only notify the Widgets, if condition is true.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited