ValidatePaymentModel class

Constructors

ValidatePaymentModel({String? responseCode, String? message, String? transactionAmount, String? charges, String? gST, String? totalPayable})
ValidatePaymentModel.fromJson(Map<String, dynamic> json)

Properties

charges String?
getter/setter pair
gST String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
message String?
getter/setter pair
responseCode String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalPayable String?
getter/setter pair
transactionAmount String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited