AccountValidationModel class

Response_Code : "1000" Message : "Success" Name : "DEEPAK SONI" MsgID : "TCA11963596D01E496E98C5C5E06DE92BE1" NPCIResp : "PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiIHN0YW5kYWxvbmU9InllcyI/PjxuczI6QWNrIHhtbG5zOm5zMj0iaHR0cDovL25wY2kub3JnL3VwaS9zY2hlbWEvIiBhcGk9IlJlcVZhbEFkZCIgcmVxTXNnSWQ9IlRDQTExOTYzNTk2RDAxRTQ5NkU5OEM1QzVFMDZERTkyQkUxIiB0cz0iMjAyNC0xMC0xNVQxMDowOToxNCswNTozMCIvPg=="

Constructors

AccountValidationModel({String? responseCode, String? message, String? name, String? msgID, String? nPCIResp})
AccountValidationModel.fromJson(dynamic json)

Properties

hashCode int
The hash code for this object.
no setterinherited
message String?
no setter
msgID String?
no setter
name String?
no setter
nPCIResp String?
no setter
responseCode String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? responseCode, String? message, String? name, String? msgID, String? nPCIResp}) AccountValidationModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited