AppUrl class
Constructors
- AppUrl()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- add_Money → const String
- BALANCE_ENQ → const String
- Bank_List → const String
- CREATE_TOKEN → const String
- create_TPIN → const String
- customer_Onboarding → const String
- fundLimit_Check → const String
- GENERATE_OTP → const String
- generateOTP → const String
- imps_charges → const String
- IMPS_Funding_Limit_Check → const String
- IMPS_Get_Beneficiery → const String
- IMPS_Recent_Transaction → const String
- IMPS_Send_Money → const String
- IMPS_Validate_Payment → const String
- IMPSAccountHolderName → const String
- IMPSNameValidation → const String
- Jan_Aadhaar_AccountValidation → const String
- Jan_Aadhaar_IFSCValidation → const String
- paymentCallBackProd → const String
- paymentCallBackstagging → const String
- resend_OTP → const String
- SESSION_TOKEN → const String
- TA_CoBrandingPG_Credit → const String
- TA_Oneapp_Feedback → const String
- TA_Oneapp_Generate_Card_PIN → const String
- TA_Oneapp_Get_Rupay_Payment_Details_Report → const String
- TA_Oneapp_GetCardStatus → const String
- TA_Oneapp_GrevienceCPFIRDatainsert → const String
- TA_Oneapp_RequestPhysicalCard → const String
- TA_Oneapp_RuPay_Block_Card → const String
- TA_Oneapp_RuPay_Change_PIN → const String
- TA_Oneapp_RuPay_Forgot_PIN → const String
- TA_Oneapp_RuPayCardGenerationRequest → const String
- TA_Oneapp_RupayEncryption3DES → const String
- TA_Oneapp_RuPayTransactionLimitUpdate → const String
- TA_Oneapp_RuPayUnblockRequest → const String
- TA_Oneapp_RuPayVerifySecurity → const String
- TA_Oneapp_UpdateChannelStatus → const String
- TA_Oneapp_ViewOriginalCard → const String
- ta_wallet_changeTpin → const String
- ta_wallet_generateOtp → const String
- ta_wallet_getBankCode → const String
- ta_wallet_getCardPayment → const String
- ta_wallet_resendOtp → const String
- ta_wallet_transactionHistory → const String
- ta_wallet_updateTpin → const String
- ta_wallet_validateOtp → const String
- ta_wallet_validateTpin → const String
- TRANSACTION_HISTORY → const String
- UPDATE_PROFILE → const String
- validat_OTP → const String
- validate_Aadhaar → const String
- VALIDATE_MOB → const String
- VALIDATE_OTP → const String
- VERIFY_TPIN → const String
- VIEW_PROFILE → const String
- View_Statement → const String