BankInfo class

Bank_ID : 29 Bankcode : "ALLN" Payment Mode : "Netbanking" Payment Channel : "Allahabad Bank NetBanking (Erstwhile Indian Bank)" Description : "Allahabad Bank NetBanking (Erstwhile Indian Bank)"

Constructors

BankInfo({num? bankID, String? bankcode, String? paymentMode, String? paymentChannel, String? description})
BankInfo.fromJson(dynamic json)

Properties

bankcode String?
no setter
bankID num?
no setter
description String?
no setter
hashCode int
The hash code for this object.
no setterinherited
paymentChannel String?
no setter
paymentMode String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({num? bankID, String? bankcode, String? paymentMode, String? paymentChannel, String? description}) BankInfo
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited