TaPayBankListModel class

Constructors

TaPayBankListModel({String? responseCode, String? message, List<BankInfo>? info})
TaPayBankListModel.fromJson(dynamic json)

Properties

hashCode int
The hash code for this object.
no setterinherited
info List<BankInfo>?
no setter
message String?
no setter
responseCode String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? responseCode, String? message, List<BankInfo>? info}) TaPayBankListModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited