TaPayInsertionModel class

Constructors

TaPayInsertionModel({String? responseCode, String? message, String? balance, String? trxnID})
TaPayInsertionModel.fromJson(dynamic json)

Properties

balance String?
no setter
hashCode int
The hash code for this object.
no setterinherited
message String?
no setter
responseCode String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trxnID String?
no setter

Methods

copyWith({String? responseCode, String? message, String? balance, String? trxnID}) TaPayInsertionModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited