loginmodel class
Constructors
- loginmodel({String? responseCode, String? message, String? janaadhaarId, String? janaadhaarMId, String? displayName, String? mobile, String? aadhaarId, String? messageRefID})
- loginmodel.fromJson(dynamic json)
Properties
- aadhaarId → String?
-
no setter
- displayName → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- janaadhaarId → String?
-
no setter
- janaadhaarMId → String?
-
no setter
- message → String?
-
no setter
- messageRefID → String?
-
no setter
- mobile → String?
-
no setter
- responseCode → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? responseCode, String? message, String? janaadhaarId, String? janaadhaarMId, String? displayName, String? mobile, String? aadhaarId, String? messageRefID}) → loginmodel -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited