Beneficiaries class
beneficiary : {"MobileNumber":"8908608223","TA_TrxnID":"","Trxn_Amount":"100.00","Status":"Scheme details not exists or expired"}
Constructors
-
Beneficiaries({List<
Beneficiary> ? beneficiary}) - Beneficiaries.fromJson(dynamic json)
Properties
-
beneficiary
→ List<
Beneficiary> ? -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< Beneficiary> ? beneficiary}) → Beneficiaries -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited