Beneficiary class
MobileNumber : "8908608223" TA_TrxnID : "" Trxn_Amount : "100.00" Status : "Scheme details not exists or expired"
Constructors
- Beneficiary({String? mobileNumber, String? tATrxnID, String? trxnAmount, String? status})
- Beneficiary.fromJson(dynamic json)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- mobileNumber → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String?
-
no setter
- tATrxnID → String?
-
no setter
- trxnAmount → String?
-
no setter
Methods
-
copyWith(
{String? mobileNumber, String? tATrxnID, String? trxnAmount, String? status}) → Beneficiary -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited