Info class

Info model

Constructors

Info({List<ManageProfile>? manageProfile, String? subWallets})
Info.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
manageProfile List<ManageProfile>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subWallets String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited