ManageProfile class
ID : 73606 MemberID : "9678568658685" SSOID : "" MobileNumber : "9797979797" NameOnCard : "AMAN" FirstName : "TEST1" LastName : "TEST2" POI : "223456349001" POA : "223456349001" POIType : "Aadhaar card" POAType : "Aadhaar card" POIVerified : "1" POAVerified : "1" Poiname : "AMAN" Poidob : "05-05-2002" Poigender : "M" Poiphone : "9797979797" Poiemail : "1305.vikar@gmail.com" Poaco : "sagar" Poadist : "" Poahouse : "" Poaloc : "" Poapc : "" Poastate : "" Poavtc : "" PoavtcCode : "" Poastreet : "" Poalm : "" Poasubdist : "" Poapo : "" Photo : "" DurationFrom : "2025-12-01" DurationTill : "2028-12-01" CreatedBy : 1 PAN : "" PANNAME : "" StatusType_ID : 1 Is_KYC_Done : 2 Created_Date : "2025-12-01T14:45:13.893" MMID : "8819645" RegisteredbyMobile : "8249652477" LoginEnable : true CustOf : 50001 Is_Distributor : false SecurityQuestion : "" SecurityAnswer : "" IsTPINEnabled : true Salt : "001B5DC0-A557-41D0-BE81-E11F72075643" LanguageCode : 1 PlatForm : "1" isUsageCapEnabled : false DailyUsageCapCount : 5 DailyUsageCapAmount : 5000.0 MPIN_encrypt : "8I2ksp8hg0Iy3RMl23gMAvibZOKRmOhfnA55SKyHMx9VeRWiLMaRXfLkSp9c2cwh6snQ2xaJy6vGfRoVl+IvZA==" TPIN_encrypt : "8I2ksp8hg0Iy3RMl23gMAvibZOKRmOhfnA55SKyHMx9VeRWiLMaRXfLkSp9c2cwh6snQ2xaJy6vGfRoVl+IvZA==" RiskStatus : "Low Risk" CurrAddIsApproved : false IsInAppOTPEnable : false isMobileNumberVerified : true isEmailIDVerified : false GeoLocation : "12.33,12.55" PDBankAccountHolderName : "" PDBankName : "" PDBankIFSC : "" PDBankAccountNo : "" PDWalletMobile : "" PlatformName : "Web" BrowserName : "" BrowserVersion : "" LoadMoneyCurrentDayCount : 0 LoadMoneyCurrentDay : 0.0 LoadMoneyCurrentMonth : 0.0 LoadMoneyCurrentYear : 0.0 IMPSCurrentDayCount : 0 IMPSCurrentDay : 0.0 IMPSCurrentMonth : 0.0 IMPSCurrentYear : 0.0 CustomerUnRegMonthTransfer : 0.0 CITIZEN_JA_MAP_STATUS : false EntityID : 86 AccountNo : "999998000073606" Balance : 0.0 LedgerBalance : 0.0
Constructors
- ManageProfile({num? id, String? memberID, String? ssoid, String? mobileNumber, String? nameOnCard, String? firstName, String? lastName, String? poi, String? poa, String? pOIType, String? pOAType, String? pOIVerified, String? pOAVerified, String? poiname, String? poidob, String? poigender, String? poiphone, String? poiemail, String? poaco, String? poadist, String? poahouse, String? poaloc, String? poapc, String? poastate, String? poavtc, String? poavtcCode, String? poastreet, String? poalm, String? poasubdist, String? poapo, String? photo, String? durationFrom, String? durationTill, num? createdBy, String? pan, String? panname, num? statusTypeID, num? isKYCDone, String? createdDate, String? mmid, String? registeredbyMobile, bool? loginEnable, num? custOf, bool? isDistributor, String? securityQuestion, String? securityAnswer, bool? isTPINEnabled, String? salt, num? languageCode, String? platForm, bool? isUsageCapEnabled, num? dailyUsageCapCount, num? dailyUsageCapAmount, String? mPINEncrypt, String? tPINEncrypt, String? riskStatus, bool? currAddIsApproved, bool? isInAppOTPEnable, bool? isMobileNumberVerified, bool? isEmailIDVerified, String? geoLocation, String? pDBankAccountHolderName, String? pDBankName, String? pDBankIFSC, String? pDBankAccountNo, String? pDWalletMobile, String? platformName, String? browserName, String? browserVersion, num? loadMoneyCurrentDayCount, num? loadMoneyCurrentDay, num? loadMoneyCurrentMonth, num? loadMoneyCurrentYear, num? iMPSCurrentDayCount, num? iMPSCurrentDay, num? iMPSCurrentMonth, num? iMPSCurrentYear, num? customerUnRegMonthTransfer, bool? citizenjamapstatus, num? entityID, String? accountNo, num? balance, num? ledgerBalance})
- ManageProfile.fromJson(dynamic json)
Properties
- accountNo → String?
-
no setter
- balance → num?
-
no setter
- browserName → String?
-
no setter
- browserVersion → String?
-
no setter
- citizenjamapstatus → bool?
-
no setter
- createdBy → num?
-
no setter
- createdDate → String?
-
no setter
- currAddIsApproved → bool?
-
no setter
- custOf → num?
-
no setter
- customerUnRegMonthTransfer → num?
-
no setter
- dailyUsageCapAmount → num?
-
no setter
- dailyUsageCapCount → num?
-
no setter
- durationFrom → String?
-
no setter
- durationTill → String?
-
no setter
- entityID → num?
-
no setter
- firstName → String?
-
no setter
- geoLocation → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → num?
-
no setter
- iMPSCurrentDay → num?
-
no setter
- iMPSCurrentDayCount → num?
-
no setter
- iMPSCurrentMonth → num?
-
no setter
- iMPSCurrentYear → num?
-
no setter
- isDistributor → bool?
-
no setter
- isEmailIDVerified → bool?
-
no setter
- isInAppOTPEnable → bool?
-
no setter
- isKYCDone → num?
-
no setter
- isMobileNumberVerified → bool?
-
no setter
- isTPINEnabled → bool?
-
no setter
- isUsageCapEnabled → bool?
-
no setter
- languageCode → num?
-
no setter
- lastName → String?
-
no setter
- ledgerBalance → num?
-
no setter
- loadMoneyCurrentDay → num?
-
no setter
- loadMoneyCurrentDayCount → num?
-
no setter
- loadMoneyCurrentMonth → num?
-
no setter
- loadMoneyCurrentYear → num?
-
no setter
- loginEnable → bool?
-
no setter
- memberID → String?
-
no setter
- mmid → String?
-
no setter
- mobileNumber → String?
-
no setter
- mPINEncrypt → String?
-
no setter
- nameOnCard → String?
-
no setter
- pan → String?
-
no setter
- panname → String?
-
no setter
- pDBankAccountHolderName → String?
-
no setter
- pDBankAccountNo → String?
-
no setter
- pDBankIFSC → String?
-
no setter
- pDBankName → String?
-
no setter
- pDWalletMobile → String?
-
no setter
- photo → String?
-
no setter
- platForm → String?
-
no setter
- platformName → String?
-
no setter
- poa → String?
-
no setter
- poaco → String?
-
no setter
- poadist → String?
-
no setter
- poahouse → String?
-
no setter
- poalm → String?
-
no setter
- poaloc → String?
-
no setter
- poapc → String?
-
no setter
- poapo → String?
-
no setter
- poastate → String?
-
no setter
- poastreet → String?
-
no setter
- poasubdist → String?
-
no setter
- pOAType → String?
-
no setter
- pOAVerified → String?
-
no setter
- poavtc → String?
-
no setter
- poavtcCode → String?
-
no setter
- poi → String?
-
no setter
- poidob → String?
-
no setter
- poiemail → String?
-
no setter
- poigender → String?
-
no setter
- poiname → String?
-
no setter
- poiphone → String?
-
no setter
- pOIType → String?
-
no setter
- pOIVerified → String?
-
no setter
- registeredbyMobile → String?
-
no setter
- riskStatus → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- salt → String?
-
no setter
- securityAnswer → String?
-
no setter
- securityQuestion → String?
-
no setter
- ssoid → String?
-
no setter
- statusTypeID → num?
-
no setter
- tPINEncrypt → String?
-
no setter
Methods
-
copyWith(
{num? id, String? memberID, String? ssoid, String? mobileNumber, String? nameOnCard, String? firstName, String? lastName, String? poi, String? poa, String? pOIType, String? pOAType, String? pOIVerified, String? pOAVerified, String? poiname, String? poidob, String? poigender, String? poiphone, String? poiemail, String? poaco, String? poadist, String? poahouse, String? poaloc, String? poapc, String? poastate, String? poavtc, String? poavtcCode, String? poastreet, String? poalm, String? poasubdist, String? poapo, String? photo, String? durationFrom, String? durationTill, num? createdBy, String? pan, String? panname, num? statusTypeID, num? isKYCDone, String? createdDate, String? mmid, String? registeredbyMobile, bool? loginEnable, num? custOf, bool? isDistributor, String? securityQuestion, String? securityAnswer, bool? isTPINEnabled, String? salt, num? languageCode, String? platForm, bool? isUsageCapEnabled, num? dailyUsageCapCount, num? dailyUsageCapAmount, String? mPINEncrypt, String? tPINEncrypt, String? riskStatus, bool? currAddIsApproved, bool? isInAppOTPEnable, bool? isMobileNumberVerified, bool? isEmailIDVerified, String? geoLocation, String? pDBankAccountHolderName, String? pDBankName, String? pDBankIFSC, String? pDBankAccountNo, String? pDWalletMobile, String? platformName, String? browserName, String? browserVersion, num? loadMoneyCurrentDayCount, num? loadMoneyCurrentDay, num? loadMoneyCurrentMonth, num? loadMoneyCurrentYear, num? iMPSCurrentDayCount, num? iMPSCurrentDay, num? iMPSCurrentMonth, num? iMPSCurrentYear, num? customerUnRegMonthTransfer, bool? citizenjamapstatus, num? entityID, String? accountNo, num? balance, num? ledgerBalance}) → ManageProfile -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited