Info class
Constructors
- Info({int? iD, String? trxnDate, String? transactionType, String? orderID, String? transactionID, String? referenceNo, String? transactionRemarks, String? credit, String? debit, String? balance, String? trxnStatus, String? parameterInfo, String? optional1, String? optional2, String? optional3, String? optional4, String? optional5, String? optional6, String? customerID, String? billerId, String? billerCategory})
-
Info.fromJson(Map<
String, dynamic> json)
Properties
- balance ↔ String?
-
getter/setter pair
- billerCategory ↔ String?
-
getter/setter pair
- billerId ↔ String?
-
getter/setter pair
- credit ↔ String?
-
getter/setter pair
- customerID ↔ String?
-
getter/setter pair
- debit ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- iD ↔ int?
-
getter/setter pair
- optional1 ↔ String?
-
getter/setter pair
- optional2 ↔ String?
-
getter/setter pair
- optional3 ↔ String?
-
getter/setter pair
- optional4 ↔ String?
-
getter/setter pair
- optional5 ↔ String?
-
getter/setter pair
- optional6 ↔ String?
-
getter/setter pair
- orderID ↔ String?
-
getter/setter pair
- parameterInfo ↔ String?
-
getter/setter pair
- referenceNo ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transactionID ↔ String?
-
getter/setter pair
- transactionRemarks ↔ String?
-
getter/setter pair
- transactionType ↔ String?
-
getter/setter pair
- trxnDate ↔ String?
-
getter/setter pair
- trxnStatus ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited