Info class
Constructors
Properties
- address → String?
-
no setter
- bank → String?
-
no setter
- branch → String?
-
no setter
- city → String?
-
no setter
- contact → String?
-
no setter
- district → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- ifsc → String?
-
no setter
- micr → dynamic
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → String?
-
no setter
Methods
-
copyWith(
{String? bank, String? ifsc, String? branch, String? contact, String? address, String? city, String? district, String? state, dynamic micr}) → Info -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited