ColorTheme class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- blackColor → const Color
- blueColor → const Color
- bordercolor → const Color
- boxBorderColor → const Color
- btnDisableColor → const Color
- chatReceivercolor → const Color
- greenbaground → const Color
- greenColor → const dynamic
- greenGrayColor → const Color
- homeiconlight → const Color
- homeplacelight → const Color
- homeToolbarColor → const Color
- loginBackColor → const Color
- loginbackcolor → const Color
- loginBorderColor → const Color
- redbaground → const Color
- redColor → const Color
- reviewTextTitleColor → const Color
- snackbarColorerror → const Color
- snackbarColorsuccess → const Color
- textfieldBackground → const Color
- textgray1Color → const Color
- textGrayColor → const Color
- unSelectedTabColor → const Color
- whitecolor → const Color
- yellowbaground → const Color