Profileviewresult class
Constructors
Properties
- accountNo → String?
-
final
- dob → String
-
final
- email → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kycStatus → String?
-
final
- memberId → String?
-
final
- mmid → String?
-
final
- mobileNo → String
-
final
- name → String
-
final
- panNumber → String?
-
final
- poi → String?
-
final
- poiType → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited